//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/GISASInstrumentEditor.cpp
//! @brief     Implements class GISASInstrumentEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/GISASInstrumentEditor.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/View/Instrument/Detail/CreateDetails.h"
#include "GUI/View/Instrument/DetectorEditor.h"
#include "GUI/View/Instrument/EnvironmentEditor.h"
#include "GUI/View/Instrument/GISASBeamEditor.h"
#include "GUI/View/Instrument/PolarizationAnalysisEditor.h"

#include <QVBoxLayout>

GISASInstrumentEditor::GISASInstrumentEditor(QWidget* parent, GISASInstrumentItem* instrument)
    : QWidget(parent)
{
    ASSERT(instrument);
    auto* layout = new QVBoxLayout(this);

    auto* beamEditor = new GISASBeamEditor(this, instrument->beamItem());
    layout->addWidget(GUI::Detail::createDetailsWidget(beamEditor, "Beam parameters"));

    auto* detectorEditor = new DetectorEditor(this, instrument);
    layout->addWidget(GUI::Detail::createDetailsWidget(detectorEditor, "Detector parameters"));

    auto* polpairAnalysisEditor = new PolarizationAnalysisEditor(this, instrument);
    layout->addWidget(GUI::Detail::createDetailsWidget(
        polpairAnalysisEditor, "Polarization analysis", /*expanded*/ false));

    auto* environmentEditor = new EnvironmentEditor(this, instrument);
    layout->addWidget(GUI::Detail::createDetailsWidget(environmentEditor, "Environment",
                                                       /*expanded*/ false));

    layout->addStretch();

    connect(beamEditor, &GISASBeamEditor::dataChanged, this, &GISASInstrumentEditor::dataChanged);
    connect(detectorEditor, &DetectorEditor::dataChanged, this,
            &GISASInstrumentEditor::dataChanged);
    connect(polpairAnalysisEditor, &PolarizationAnalysisEditor::dataChanged, this,
            &GISASInstrumentEditor::dataChanged);
    connect(environmentEditor, &EnvironmentEditor::dataChanged, this,
            &GISASInstrumentEditor::dataChanged);
}
